@@ -7,12 +7,16 @@ from cardutil.outputter import dicts_to_csv
 
 
 def cli_entry():
-    args = vars(cli_parser().parse_args())
-    if not args['out_filename']:
-        args['out_filename'] = args['in_filename'] + '.csv'
+    cli_run(**vars(cli_parser().parse_args()))
 
-    with open(args['in_filename'], 'rb') as in_ipm, open(args['out_filename'], 'w') as out_csv:
-        mci_ipm_to_csv(in_ipm=in_ipm, out_csv=out_csv, **args)
+
+def cli_run(**kwargs):
+    if not kwargs.get('out_filename'):
+        kwargs['out_filename'] = kwargs['in_filename'] + '.csv'
+
+    with open(kwargs['in_filename'], 'rb') as in_ipm:
+        with open(kwargs['out_filename'], 'w', encoding=kwargs['out_encoding']) as out_csv:
+            mci_ipm_to_csv(in_ipm=in_ipm, out_csv=out_csv, **kwargs)
 
 
 def cli_parser():
@@ -20,6 +24,7 @@ def cli_parser():
     parser.add_argument('in_filename')
     parser.add_argument('-o', '--out-filename')
     parser.add_argument('--in-encoding', default='ascii')
+    parser.add_argument('--out-encoding', default='ascii')
     parser.add_argument('--no1014blocking', action='store_true')
     add_version(parser)
 
